[−][src]Struct jwt_compact_preview::alg::Es256k
Algorithm implementing elliptic curve digital signatures (ECDSA) on the secp256k1 curve.
The algorithm does not fix the choice of the message digest algorithm; instead, it is provided as a type parameter. SHA-256 is the default parameter value, but it can be set to any cryptographically secure hash function with 32-byte output (e.g., SHA3-256).
This type is available if the crate is built with the secp256k1 feature.
Implementations
impl<D> Es256k<D> where
D: Digest<OutputSize = U32> + Default, [src]
D: Digest<OutputSize = U32> + Default,
pub fn new(context: Secp256k1<All>) -> Self[src]
Creates a new algorithm instance.
This is a (moderately) expensive operation, so if necessary, the algorithm should
be clone()d rather than created anew.
impl Es256k[src]
pub fn generate<R: CryptoRng + RngCore>(
&self,
rng: &mut R
) -> (Es256kSigningKey, Es256kVerifyingKey)[src]
&self,
rng: &mut R
) -> (Es256kSigningKey, Es256kVerifyingKey)
Generate a new key pair.