pub enum ValidationError {
AlgorithmMismatch,
MalformedSignature(Error),
InvalidSignature,
MalformedClaims(Error),
MalformedCborClaims(Error),
NoClaim,
Expired,
NotMature,
}Expand description
Errors that can occur during token validation.
Variants
AlgorithmMismatch
Algorithm mentioned in the token header differs from invoked one.
MalformedSignature(Error)
Token signature is malformed (e.g., has an incorrect length).
InvalidSignature
Token signature has failed verification.
MalformedClaims(Error)
Token claims cannot be deserialized from JSON.
MalformedCborClaims(Error)
Token claims cannot be deserialized from CBOR.
NoClaim
Claim requested during validation is not present in the token.
Expired
Token has expired.
NotMature
Token is not yet valid as per nbf claim.