pub struct Header {
pub key_set_url: Option<String>,
pub key_id: Option<String>,
pub certificate_url: Option<String>,
pub certificate_thumbprint: Option<String>,
pub signature_type: Option<String>,
}Expand description
JWT header.
See RFC 7515 for the description
of the fields. The purpose of all fields except signature_type is to determine
the verifying key. Since these values will be provided by the adversary in the case of
an attack, they require additional verification (e.g., a provided certificate might
be checked against the list of “acceptable” certificate authorities).
Fields
key_set_url: Option<String>URL of the JSON Web Key Set containing the key that has signed the token.
This field is renamed to jku for serialization.
key_id: Option<String>Identifier of the key that has signed the token. This field is renamed to kid
for serialization.
certificate_url: Option<String>URL of the X.509 certificate for the signing key. This field is renamed to x5u
for serialization.
certificate_thumbprint: Option<String>Thumbprint of the X.509 certificate for the signing key. This field is renamed to x5t
for serialization.
signature_type: Option<String>Application-specific signature type. This field is renamed to typ for serialization.