pub struct Ed25519;Expand description
Integrity algorithm using digital signatures on the Ed25519 elliptic curve.
The name of the algorithm is specified as EdDSA as per the IANA registry.
Use with_specific_name() to switch to non-standard Ed25519.
This type is available if the crate is built with the ed25519-compact feature.
Implementations
Sourceimpl Ed25519
impl Ed25519
Sourcepub fn with_specific_name() -> Renamed<Self>
pub fn with_specific_name() -> Renamed<Self>
Creates an algorithm instance with the algorithm name specified as Ed25519.
This is a non-standard name, but it is used in some apps.
Sourcepub fn generate<R: CryptoRng + RngCore>(
&self,
rng: &mut R,
) -> (Ed25519SigningKey, Ed25519VerifyingKey)
pub fn generate<R: CryptoRng + RngCore>( &self, rng: &mut R, ) -> (Ed25519SigningKey, Ed25519VerifyingKey)
Generate a new key pair.