[−][src]Struct jwt_compact_preview::alg::Es256
Algorithm implementing elliptic curve digital signatures (ECDSA) on the secp256k1 curve.
The algorithm does not fix the choice of the message digest algorithm; instead, it is provided as a type parameter. SHA-256 is the default parameter value, but it can be set to any cryptographically secure hash function with 32-byte output (e.g., SHA3-256).
This type is available if the crate is built with the k256 feature.
Implementations
impl<R: CryptoRng + RngCore> Es256<R>[src]
impl<R: CryptoRng + RngCore> Es256<R>[src]
pub fn generate(&mut self) -> (Es256SigningKey, Es256VerifyingKey)[src]
Generate a new key pair.