[][src]Struct jwt_compact_preview::alg::Rsa

pub struct Rsa { /* fields omitted */ }

Integrity algorithm using digital signatures on RSA-PKCS1v1.5 and SHA-256.

The name of the algorithm is specified as RS256 as per the IANA registry.

This type is available if the crate is built with the rsa feature.

Implementations

impl Rsa[src]

pub fn new(hash_alg: Hash, padding_alg: Padding) -> Self[src]

Create an instance using a specific hash function and padding

impl Rsa[src]

pub fn generate<R: CryptoRng + RngCore>(
    rng: &mut R,
    modulus_bits: usize
) -> Result<(RsaSigningKey, RsaVerifyingKey)>
[src]

Generate a new key pair.